/* pll_desc.h - structures for PLL chip definition
 * Copyright (C) 2003 Georg Lukas <georg@boerde.de>
 * (This Program is under the GNU General Public License)
 */

#ifndef PLL_DESC_H
#define PLL_DESC_H

#define STRLEN 32

/* defines a PLL command as: reg[regpos] = (reg[regpos] & andmask) | ormask;
 *     you can do pretty cool things with that, examples are:
 *            andmask=0x00; ormask=0x1F -> set byte to 0x1F
 *            andmask=0x7F; ormask=0x80 -> set bit 7 (0x80) and keep the rest
 */
typedef struct {
	unsigned char regpos;
	unsigned char andmask;
	unsigned char ormask;
} pll_cmd;

/* FSB_DEF as FSB means, this is the default setting, and we don't know the clocks */
#define FSB_DEF -1
typedef struct {
	int fsb;
	int pci;
	int mem;
	pll_cmd c;
} pll_fsb_mapping;

typedef struct {
	unsigned char name[STRLEN];
	pll_cmd on;
	pll_cmd off;
} pll_feature;

typedef unsigned char *pll_board;

typedef struct {
	unsigned char name[STRLEN];
	unsigned char comment[64];
	unsigned char i2c_addr;
	pll_feature *features;
	pll_fsb_mapping *fsbs;
	pll_board *boards; /* I'm shooting into my feet with this! */
} pll;


#endif // PLL_DESC_H

